@extends('website.main')
@section('main-content')

	<section class="hero-wrap hero-wrap-2" style="background-image: url('{{ asset('assets/images/bag2.webp') }}');">
		<div class="overlay"></div>
		<div class="container">
			<div class="row no-gutters slider-text align-items-center justify-content-center">
				<div class="col-md-9 pt-5 text-center">
					<p class="breadcrumbs"><span class="mr-2"><a href="{{ route('home') }}">Home
								<i class="fa fa-chevron-right"></i></a></span> <span>Our Services <i
								class="fa fa-chevron-right"></i></span></p>
					<h1 class="mb-0 bread">Our Services</h1>
				</div>
			</div>
		</div>
	</section>
@include('website.partials.practiceareas')


@endsection
