<!DOCTYPE html>
<html lang="en">
@include('dashboard.partials.head')

<body>
    <div class="wrapper">
      @include('dashboard.partials.sidebar')

        <div class="main">
            @include('dashboard.partials.navbar')

            <main class="content">
                <div class="container-fluid p-0">




                    <div class="row">
                        <div class="col-12 d-flex">




                                @yield('main-content')


                        </div>

                    </div>

                </div>
            </main>
            @include('dashboard.partials.footer')
        </div>
    </div>

    <script src="{{ asset('dashboard_assets/js/app.js') }}"></script>


</body>

</html>
