<?php $__env->startSection('main-content'); ?>
<style>
    .icon-box{
    width:65px;
    height:65px;
    border-radius:50%;
    display:flex;
    align-items:center;
    justify-content:center;
    color:#fff;
    font-size:26px;
}

.card{
    border-radius:15px;
    transition:.3s;
}

.card:hover{
    transform:translateY(-6px);
    box-shadow:0 15px 35px rgba(0,0,0,.15)!important;
}

.bg-primary{
    background:#1F3044!important;
}

.bg-success{
    background:#198754!important;
}

.bg-warning{
    background:#d4a017!important;
}

.bg-danger{
    background:#dc3545!important;
}


.dashboard-card{
    position:relative;
    background:#fff;
    border-radius:18px;
    padding:30px;
    overflow:hidden;
    transition:.35s;
    box-shadow:0 10px 30px rgba(0,0,0,.06);
    border-left:6px solid #1F3044;
    min-height:180px;
}

.dashboard-card:hover{
    transform:translateY(-8px);
    box-shadow:0 18px 40px rgba(0,0,0,.15);
}

.card-icon{
    width:65px;
    height:65px;
    border-radius:50%;
    display:flex;
    justify-content:center;
    align-items:center;
    color:#fff;
    font-size:26px;
    position:absolute;
    right:25px;
    top:25px;
}

.card-content span{
    color:#8b8b8b;
    font-size:15px;
    text-transform:uppercase;
    letter-spacing:1px;
}

.card-content h2{
    margin-top:15px;
    font-size:48px;
    font-weight:700;
    color:#1F3044;
}

.card-content small{
    color:#888;
    font-size:14px;
}

.border-primary{
    border-left-color:#1F3044;
}

.border-success{
    border-left-color:#198754;
}

.border-warning{
    border-left-color:#d4a017;
}

.border-danger{
    border-left-color:#dc3545;
}

.bg-primary{
    background:#1F3044;
}

.bg-success{
    background:#198754;
}

.bg-warning{
    background:#d4a017;
}

.bg-danger{
    background:#dc3545;
}
</style>
<div class="container-fluid">

    <div class="d-flex justify-content-between align-items-center mb-4">
        <h2 class="fw-bold">
            Dashboard
        </h2>

        <span class="text-muted">
            Welcome Back!
        </span>
    </div>

 <div class="row g-4">

    <!-- Contact Forms -->
    <div class="col-lg-3 col-md-6">
        <div class="dashboard-card border-primary">
            <div class="card-icon bg-primary">
                <i class="fas fa-envelope"></i>
            </div>

            <div class="card-content">
                <span>Contact Forms</span>
                <h2><?php echo e($totalContacts); ?></h2>
                <small>Total Contact Submissions</small>
            </div>
        </div>
    </div>

    <!-- Job Applications -->
    <div class="col-lg-3 col-md-6">
        <div class="dashboard-card border-success">
            <div class="card-icon bg-success">
                <i class="fas fa-briefcase"></i>
            </div>

            <div class="card-content">
                <span>Applications</span>
                <h2><?php echo e($totalApplications); ?></h2>
                <small>Total Job Applications</small>
            </div>
        </div>
    </div>

    <!-- Blogs -->
    <div class="col-lg-3 col-md-6">
        <div class="dashboard-card border-warning">
            <div class="card-icon bg-warning">
                <i class="fas fa-blog"></i>
            </div>

            <div class="card-content">
                <span>Blogs</span>
                <h2><?php echo e($totalBlogs); ?></h2>
                <small>Total Published Blogs</small>
            </div>
        </div>
    </div>

    <!-- Users -->
    <div class="col-lg-3 col-md-6">
        <div class="dashboard-card border-danger">
            <div class="card-icon bg-danger">
                <i class="fas fa-users"></i>
            </div>

            <div class="card-content">
                <span>Users</span>
                <h2><?php echo e($totalUsers); ?></h2>
                <small>Registered Users</small>
            </div>
        </div>
    </div>

</div>
</div>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('dashboard.main', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/dashboard/dashboard.blade.php ENDPATH**/ ?>