 <div class="desktop-header pb-5 top-wrap">
     <div class="container-xl">
         <div class="row d-flex align-items-end">

             <!-- Logo -->
             <div class="col-md-4 d-flex justify-content-center mb-2 mb-md-0">
                 <a class="navbar-brand m-0 p-0" href="{{ route('home') }}">
                     <img src=" {{ asset('assets/images/logotrans.png-1') }}" alt="Aljubail Law Firm Logo"
                         class="img-fluid logo-img">
                 </a>
             </div>

             <!-- Location -->
             <div class="col-md topper d-flex mb-md-0 align-items-center">
                 <div class="icon d-flex justify-content-center align-items-center">
                     <span class="fa fa-map"></span>
                 </div>
                 <div class="text pl-3">
                     <p class="hr"><span style="color: #1F3044;">Our Location</span></p>
                     <p class="con" style="color: #1F3044;">Riyadh Al-Ulya, King Fahd Road, Marabaa Tower</p>
                 </div>
             </div>

             <!-- Call -->
             <div class="col-md topper d-flex mb-md-0 mb-2 align-items-center">
                 <div class="icon d-flex justify-content-center align-items-center">
                     <span class="fa fa-phone"></span>
                 </div>
                 <div class="text pl-3">
                     <p class="con" style="color: #1F3044;"><span style="color: #1F3044;">+966-554944497</span></p>
                     <p class="con" style="color: #1F3044;">Call Us Now 24/7 Customer Support</p>
                 </div>
             </div>

         </div>
     </div>
     <nav class="navbar navbar-expand-lg ftco-navbar-light">

         <div class="container-xl">

             <div class="collapse navbar-collapse show">

                 <ul class="navbar-nav mr-auto">

                     <!-- Home -->
                     <li class="nav-item active">
                         <a class="nav-link" href="{{ route('home') }}">
                             Home
                         </a>
                     </li>


                     <!-- Services -->
                     <li class="nav-item dropdown">

    <a class="nav-link dropdown-toggle"
       href="#"
       id="servicesDropdown"
       role="button"
       data-bs-toggle="dropdown"
       aria-expanded="false">

        Our Services

    </a>

    <ul class="dropdown-menu">

        <li>
            <a class="dropdown-item" href="{{ route('commercial.financial.disputes') }}">
                Commercial & Financial Disputes
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('commercial.contracts') }}">
                Drafting & Reviewing Commercial Contracts
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('tax.disputes') }}">
                Tax Disputes
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('labour.employment') }}">
                Labor & Employment Law
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('foreign.investment') }}">
                Foreign Investment
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('intellectual.property') }}">
                Intellectual Property Rights
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('banking.finance') }}">
                Banking & Finance Disputes
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('commercial.arbitration') }}">
                Commercial Arbitration, Mediation & Amicable Settlement
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('bankruptcy') }}">
                Bankruptcy & Financial Restructuring
            </a>
        </li>

        <li>
            <a class="dropdown-item" href="{{ route('corporate.law') }}">
                Corporate Law & Governance
            </a>
        </li>

    </ul>

</li>

                     <!-- Practice Areas -->
                     <li class="nav-item">
                         <a class="nav-link" href="{{ route('practice.areas') }}">
                             Practice Areas
                         </a>
                     </li>


                     <!-- About Dropdown -->
                     <li class="nav-item dropdown">

                         <a class="nav-link dropdown-toggle" href="{{ route('about') }}" id="aboutDropdown"
                             role="button" data-bs-toggle="dropdown" aria-expanded="false">

                             About Us

                         </a>

                         <ul class="dropdown-menu">

                             <li>
                                 <a class="dropdown-item" href="{{ route('about') }}">
                                     About Us
                                 </a>
                             </li>

                             <li>
                                 <a class="dropdown-item" href="{{ route('team') }}">
                                     Our Team
                                 </a>
                             </li>

                             <li>
                                 <a class="dropdown-item" href="{{ route('careers') }}">
                                     Career
                                 </a>
                             </li>

                             <li>
                                 <a class="dropdown-item" href="{{ route('blogs') }}">
                                     Blog
                                 </a>
                             </li>

                         </ul>

                     </li>


                     <!-- Contact -->
                     <li class="nav-item">
                         <a class="nav-link" href="{{ route('contact') }}">
                             Contact Us
                         </a>
                     </li>


                     <!-- Language -->
                     <li class="nav-item dropdown">

                         <a class="nav-link dropdown-toggle" href="#" id="languageDropdown" role="button"
                             data-bs-toggle="dropdown" aria-expanded="false">

                             🌐 Language

                         </a>

                         <ul class="dropdown-menu dropdown-menu-end">

                             <li>
                                 <a class="dropdown-item" href="{{ route('home') }}">
                                     🇬🇧 English
                                 </a>
                             </li>

                             <li>
                                 <a class="dropdown-item" href="#">
                                     🇸🇦 العربية
                                 </a>
                             </li>

                         </ul>

                     </li>

                 </ul>


                 <!-- Call Button -->
                 <a href="tel:+966554944497" class="nav-call-btn">

                     <div class="call-icon-wrap">
                         <i class="fa-solid fa-phone"></i>
                     </div>

                     <div class="call-text-wrap">
                         <span class="call-title">
                             Call Us Now
                         </span>

                         <span class="call-number">
                             +966-554944497
                         </span>
                     </div>

                 </a>

             </div>

         </div>

     </nav>
 </div>



 <!-- ================= Mobile Header ================= -->
 <style>
     .mobile-header {
         background: #fff;
         border-bottom: 1px solid #e8e8e8;
     }

     .mobile-logo img {
         height: 70px;
     }

     .mobile-toggler {
         background: #1F3044;
         color: #fff;
         width: 45px;
         height: 45px;
         border-radius: 8px;
         font-size: 20px;
     }

     .mobile-menu {
         background: #fff;
     }

     .mobile-menu-header {
         background: #1F3044;
         padding: 20px;
     }

     .mobile-menu-header img {
         height: 60px;
     }

     .mobile-menu-header button {
         color: #fff;
     }

     .mobile-menu ul li {
         border-bottom: 1px solid #ececec;
     }

     .mobile-menu ul li a {
         color: #1F3044;
         font-weight: 600;
         display: flex;
         justify-content: space-between;
         align-items: center;
     }

     .mobile-menu ul li a:hover {
         background: #1F3044;
         color: #fff;
     }

     .mobile-menu ul li a:hover i {
         color: #fff;
     }

     .submenu {
         background: #f8f9fa;
     }

     .submenu li a {
         color: #495057;
         padding-left: 40px !important;
     }

     .submenu li a:hover {
         background: #e9ecef;
         color: #1F3044;
     }

     .mobile-overlay {
         background: rgba(31, 48, 68, .45);
     }
 </style>
 <div class="mobile-header">

     <div class="container-fluid">

         <div class="d-flex justify-content-between align-items-center">

             <a href="{{ route('home') }}" class="mobile-logo">

                 <img src=" {{ asset('assets/images/logotrans.png-1') }}" alt="Logo">

             </a>

             <button id="menuToggle" class="mobile-toggler">

                 <i class="fa fa-bars"></i>

             </button>

         </div>

     </div>

 </div>



 <!-- Overlay -->

 <div class="mobile-overlay"></div>



 {{-- <!-- ================= Mobile Sidebar ================= -->

 <div class="mobile-menu">

     <div class="mobile-menu-header">

         <img src=" {{ asset('assets/images/logotrasn.png') }}" class="pt-3" alt="Logo">

         <button id="closeMenu">

             <i class="fa fa-times"></i>

         </button>

     </div>


     <ul>

         <li>

             <a href="index.html">
                 Home
             </a>

         </li>

         <li>

             <a href="about.html">
                 About Us
             </a>

         </li>


         <li class="mobile-dropdown">

             <a href="javascript:void(0);">

                 Our Services

                 <i class="fa fa-angle-down float-right"></i>

             </a>

             <ul class="submenu">

                 <li>
                     <a href="#">
                         Commercial & Financial Disputes
                     </a>
                 </li>

                 <li>
                     <a href="#">
                         Commercial Contracts
                     </a>
                 </li>

                 <li>
                     <a href="#">
                         Tax Disputes
                     </a>
                 </li>

                 <li>
                     <a href="#">
                         Labor & Employment Law
                     </a>
                 </li>

                 <li>
                     <a href="#">
                         Foreign Investment
                     </a>
                 </li>

                 <li>
                     <a href="#">
                         Corporate Law
                     </a>
                 </li>

             </ul>

         </li>

         <li>

             <a href="team.html">
                 Our Team
             </a>

         </li>

         <li>

             <a href="blog.html">
                 Blog
             </a>

         </li>

         <li>

             <a href="contact.html">
                 Contact Us
             </a>

         </li>

         <li>

             <a href="Arabic.html">
                 العربية
             </a>

         </li>

     </ul>
 </div>
 --}}


 <!-- Overlay -->

 <div class="mobile-overlay"></div>



 <!-- ================= Mobile Sidebar ================= -->
<div class="mobile-menu">

    <!-- Header -->
    <div class="mobile-menu-header">

        <img src="{{ asset('assets/images/logotrasn.png') }}" alt="Logo">

        <button id="closeMenu">
            <i class="fa fa-times"></i>
        </button>

    </div>


    <ul>

        <!-- Home -->
        <li>
            <a href="{{ route('home') }}">
                Home
            </a>
        </li>


        <!-- Services -->
        <li class="mobile-dropdown">

            <a href="javascript:void(0);">

                Our Services

                <i class="fa fa-angle-down"></i>

            </a>

       <ul class="submenu">

    <li>
        <a href="{{ route('commercial.financial.disputes') }}">
            Commercial & Financial Disputes
        </a>
    </li>

    <li>
        <a href="{{ route('commercial.contracts') }}">
            Drafting & Reviewing Commercial Contracts
        </a>
    </li>

    <li>
        <a href="{{ route('tax.disputes') }}">
            Tax Disputes
        </a>
    </li>

    <li>
        <a href="{{ route('labour.employment') }}">
            Labor & Employment Law
        </a>
    </li>

    <li>
        <a href="{{ route('foreign.investment') }}">
            Foreign Investment
        </a>
    </li>

    <li>
        <a href="{{ route('intellectual.property') }}">
            Intellectual Property Rights
        </a>
    </li>

    <li>
        <a href="{{ route('banking.finance') }}">
            Banking & Finance Disputes
        </a>
    </li>

    <li>
        <a href="{{ route('commercial.arbitration') }}">
            Commercial Arbitration, Mediation & Amicable Settlement
        </a>
    </li>

    <li>
        <a href="{{ route('bankruptcy') }}">
            Bankruptcy & Financial Restructuring
        </a>
    </li>

    <li>
        <a href="{{ route('corporate.law') }}">
            Corporate Law & Governance
        </a>
    </li>

</ul>
        </li>


        <!-- Practice Areas -->
        <li>
            <a href="{{ route('practice.areas') }}">
                Practice Areas
            </a>
        </li>


        <!-- About -->
        <li class="mobile-dropdown">

            <a href="javascript:void(0);">

                About Us

                <i class="fa fa-angle-down"></i>

            </a>

            <ul class="submenu">

                <li>
                    <a href="{{ route('about') }}">
                        About Us
                    </a>
                </li>

                <li>
                    <a href="{{ route('team') }}">
                        Our Team
                    </a>
                </li>

                <li>
                    <a href="{{ route('careers') }}">
                        Career
                    </a>
                </li>

                <li>
                    <a href="{{ route('blogs') }}">
                        Blog
                    </a>
                </li>

            </ul>

        </li>


        <!-- Contact -->
        <li>
            <a href="{{ route('contact') }}">
                Contact Us
            </a>
        </li>


        <!-- Language -->
        <li class="mobile-dropdown">

            <a href="javascript:void(0);">

                🌐 Language

                <i class="fa fa-angle-down"></i>

            </a>

            <ul class="submenu">

                <li>
                    <a href="{{ route('home') }}">
                        🇬🇧 English
                    </a>
                </li>
                <li>
                    <a href="#">
                        🇸🇦 العربية
                    </a>
                </li>

            </ul>

        </li>
    </ul>

</div>
