
	<section class="ftco-section" style="background-color: #F5F7FA;">
		<div class="container-xl">
			<div class="row justify-content-center">
				<div class="col-md-5 heading-section text-center mb-5" data-aos="fade-up" data-aos-duration="1000">
					<span class="subheading">Practice Areas</span>
					<h2 class="mb-4">Clear Advice Providers</h2>
				</div>
			</div>


			<div class="row g-4 justify-content-center">

				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000">
						<div class="img" style="background-image: url(images/Commercial\ &\ Financial\ Disputes.jfif);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-scale-balanced" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Commercial & Financial Disputes</a></h3>
							<p>Handling complex corporate conflicts, breach of contract claims, and financial litigation
								with strategic legal representation.</p>
						</div>
					</div>
				</div>

				<!-- 2. Commercial Contracts -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="100">
						<div class="img" style="background-image: url(images/Commercial_Contracts.jpg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-file-signature" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Commercial Contracts</a></h3>
							<p>Drafting, reviewing, and negotiating robust commercial agreements to safeguard your
								business interests and minimize legal risks.</p>
						</div>
					</div>
				</div>

				<!-- 3. Tax Disputes -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="200">
						<div class="img" style="background-image: url(images/TAX_disputes.jpeg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-file-invoice-dollar" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Tax Disputes</a></h3>
							<p>Providing expert counsel and defense before tax authorities and tribunals regarding
								assessments, compliance, and audits.</p>
						</div>
					</div>
				</div>

				<!-- 4. Labor & Employment Law -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="300">
						<div class="img" style="background-image: url(images/labour.jfif);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-users" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Labor & Employment Law</a></h3>
							<p>Advising on employer obligations, employee rights, employment contracts, workforce
								policies, and labor court disputes.</p>
						</div>
					</div>
				</div>

				<!-- 5. Foreign Investment -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="400">
						<div class="img" style="background-image: url(images/Foreign\ Investment.jpg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-earth-asia" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Foreign Investment</a></h3>
							<p>Assisting international investors with market entry, regulatory compliance, cross-border
								transactions, and entity setup.</p>
						</div>
					</div>
				</div>

				<!-- 6. Intellectual Property -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="500">
						<div class="img" style="background-image: url(images/Intellectual\ Property.jpg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-lightbulb" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Intellectual Property</a></h3>
							<p>Protecting patents, trademarks, copyrights, and trade secrets through strategic
								registration and enforcement litigation.</p>
						</div>
					</div>
				</div>

				<!-- 7. Banking & Finance -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="100">
						<div class="img" style="background-image: url(images/Banking\ &\ Finance.jpg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-building-columns" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Banking & Finance</a></h3>
							<p>Offering specialized advice on financial regulatory compliance, loan documentation,
								structured finance, and banking claims.</p>
						</div>
					</div>
				</div>

				<!-- 8. Arbitration & Mediation -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="200">
						<div class="img" style="background-image: url(images/Arbitration\ &\ Mediation.jfif);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-handshake" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Arbitration & Mediation</a></h3>
							<p>Resolving commercial disputes efficiently out of court through alternative dispute
								resolution and international arbitration.</p>
						</div>
					</div>
				</div>
				<!-- 9. Bankruptcy
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="300">
						<div class="img"
							style="background-image: url(images/practice-1.jpg);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-sack-dollar" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="bankruptcy.html">Bankruptcy & Insolvency</a></h3>
							<p>Guiding businesses through financial restructuring, debt settlement, insolvency
								proceedings, and liquidation processes.</p>
						</div>
					</div>
				</div> -->

				<!-- 10. Corporate Law -->
				<div class="col-md-6 col-lg-4">
					<div class="practice-areas" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="400">
						<div class="img" style="background-image: url(images/Corporate\ Law.jfif);">
						</div>
						<div class="text">
							<div class="icon d-flex align-items-center justify-content-center">
								<i class="fa-solid fa-briefcase" style="color:  #1F3044; font-size: 34px;"></i>
							</div>
							<h3><a href="service.html">Corporate Law</a></h3>
							<p>Full-spectrum corporate governance, legal structuring, mergers & acquisitions, and
								continuous regulatory advisory.</p>
						</div>
					</div>
				</div>

			</div>
		</div>
	</section>
