		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/devanagari/300/normal.woff2);
			unicode-range: U+0900-097F, U+1CD0-1CF9, U+200C-200D, U+20A8, U+20B9, U+20F0, U+25CC, U+A830-A839, U+A8E0-A8FF, U+11B00-11B09;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin/300/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin-ext/300/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin/400/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin-ext/400/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/devanagari/400/normal.woff2);
			unicode-range: U+0900-097F, U+1CD0-1CF9, U+200C-200D, U+20A8, U+20B9, U+20F0, U+25CC, U+A830-A839, U+A8E0-A8FF, U+11B00-11B09;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin/500/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin-ext/500/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/devanagari/500/normal.woff2);
			unicode-range: U+0900-097F, U+1CD0-1CF9, U+200C-200D, U+20A8, U+20B9, U+20F0, U+25CC, U+A830-A839, U+A8E0-A8FF, U+11B00-11B09;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin-ext/600/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin/600/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/devanagari/600/normal.woff2);
			unicode-range: U+0900-097F, U+1CD0-1CF9, U+200C-200D, U+20A8, U+20B9, U+20F0, U+25CC, U+A830-A839, U+A8E0-A8FF, U+11B00-11B09;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin/700/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/devanagari/700/normal.woff2);
			unicode-range: U+0900-097F, U+1CD0-1CF9, U+200C-200D, U+20A8, U+20B9, U+20F0, U+25CC, U+A830-A839, U+A8E0-A8FF, U+11B00-11B09;
			font-display: swap;
		}

		@font-face {
			font-family: Poppins;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/s/poppins/5.2.7/latin-ext/700/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}


		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin/wght/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/normal.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/normal.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/normal.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/normal.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin/wght/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/normal.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/normal.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/normal.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/normal.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/normal.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin/wght/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/normal.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/normal.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin/wght/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/normal.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/normal.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/normal.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/normal.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin/wght/normal.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: normal;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/normal.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/italic.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/italic.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/italic.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 300;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 300;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/italic.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/italic.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/italic.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/italic.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 400;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/italic.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 400;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/italic.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic/wght/italic.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/italic.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 500;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/italic.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 500;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/latin-ext/wght/italic.woff2);
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/italic.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 600;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/italic.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 600;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 600;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/vietnamese/wght/italic.woff2);
			unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169, U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323, U+0329, U+1EA0-1EF9, U+20AB;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 700;
			src: url(fonts/flaticon/font/italic.woff2);
			unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 700;
			src: url(fonts/flaticon/font/italic.woff2);
			unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 700;
			src: url('fonts/flaticon/font/italic.woff2');
			unicode-range: U+0100-02BA, U+02BD-02C5, U+02C7-02CC, U+02CE-02D7, U+02DD-02FF, U+0304, U+0308, U+0329, U+1D00-1DBF, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F, U+A720-A7FF;
			font-display: swap;
		}

		@font-face {
			font-family: Cormorant Garamond;
			font-style: italic;
			font-weight: 700;
			src: url(https://preview.colorlib.com/cf-fonts/v/cormorant-garamond/5.2.11/cyrillic-ext/wght/italic.woff2);
			unicode-range: U+0460-052F, U+1C80-1C8A, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;
			font-display: swap;
		}
		
	