	/*
  	Flaticon icon font: Flaticon
  	Creation date: 04/01/2019 13:45
  	*/

	@font-face {
	    font-family: "Flaticon";
	    src: url("../fonts/flaticon/font/Flaticon.eot");
	    src: url("../fonts/flaticon/font/Flaticon.eot?#iefix") format("embedded-opentype"), url("../fonts/flaticon/font/Flaticon.woff") format("woff"), url("../fonts/flaticon/font/Flaticon.ttf") format("truetype"), url("../fonts/flaticon/font/Flaticon.svg#Flaticon") format("svg");
	    font-weight: normal;
	    font-style: normal;
	}

	@media screen and (-webkit-min-device-pixel-ratio:0) {
	    @font-face {
	        font-family: "Flaticon";
	        src: url("../fonts/flaticon/font/Flaticon.svg#Flaticon") format("svg");
	    }
	}

	[class^="flaticon-"]:before,
	[class*=" flaticon-"]:before,
	[class^="flaticon-"]:after,
	[class*=" flaticon-"]:after {
	    font-family: Flaticon;
	    font-style: normal;
	    font-weight: normal;
	    font-variant: normal;
	    text-transform: none;
	    line-height: 1;
	    /* Better Font Rendering =========== */
	    -webkit-font-smoothing: antialiased;
	    -moz-osx-font-smoothing: grayscale;
	}

	.flaticon-law:before {
	    content: "\f100";
	}

	.flaticon-lawyer:before {
	    content: "\f101";
	}

	.flaticon-law-1:before {
	    content: "\f102";
	}

	.flaticon-success:before {
	    content: "\f103";
	}

	.flaticon-happy:before {
	    content: "\f104";
	}