<?php $__env->startSection('main-content'); ?>

	<section class="hero-wrap hero-wrap-2" style="background-image: url('<?php echo e(asset('assets/images/bag2.webp')); ?>');">
		<div class="overlay"></div>
		<div class="container">
			<div class="row no-gutters slider-text align-items-center justify-content-center">
				<div class="col-md-9 pt-5 text-center">
					<p class="breadcrumbs"><span class="mr-2"><a href="<?php echo e(route('home')); ?>">Home
								<i class="fa fa-chevron-right"></i></a></span> <span>Our Services <i
								class="fa fa-chevron-right"></i></span></p>
					<h1 class="mb-0 bread">Our Services</h1>
				</div>
			</div>
		</div>
	</section>
<?php echo $__env->make('website.partials.practiceareas', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>


<?php $__env->stopSection(); ?>

<?php echo $__env->make('website.main', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/website/practice-areas.blade.php ENDPATH**/ ?>