<?php $__env->startSection('main-content'); ?>
    <section class="hero-wrap hero-wrap-2"
        style="background-image: url('https://preview.colorlib.com/theme/atorni/images/bg_5.jpg');">
        <div class="overlay"></div>
        <div class="container">
            <div class="row no-gutters slider-text align-items-center justify-content-center">
                <div class="col-md-9 pt-5 text-center">
                    <p class="breadcrumbs"><span class="mr-2"><a
                                href="https://preview.colorlib.com/theme/atorni/index.html">Home <i
                                    class="fa fa-chevron-right"></i></a></span> <span class="mr-2"><a
                                href="https://preview.colorlib.com/theme/atorni/index.html">Blog <i
                                    class="fa fa-chevron-right"></i></a></span> <span>Blog Single <i
                                class="fa fa-chevron-right"></i></span></p>
                    <h1 class="mb-0 bread">Blog Single</h1>
                </div>
            </div>
        </div>
    </section>

    <section class="ftco-section">
        <div class="container">
            <div class="row">
                <div class="col-lg-8 blog-single">

                    <h2 class="mb-3">
                        <?php echo e($blog->title); ?>

                    </h2>

                    <p>
                        <?php echo nl2br(e($blog->short_description)); ?>

                    </p>

                    <?php if($blog->image): ?>
                        <p>
                            <img src="<?php echo e(asset('uploads/blogs/' . $blog->image)); ?>" class="img-fluid"
                                alt="<?php echo e($blog->title); ?>">
                        </p>
                    <?php endif; ?>

                    <div class="blog-content">

                        <?php echo $blog->description; ?>


                    </div>

                    <div class="tag-widget post-tag-container mb-5 mt-5">

                        <div class="tagcloud">

                            <a href="#" class="tag-cloud-link">
                                Legal
                            </a>

                            <a href="#" class="tag-cloud-link">
                                Law
                            </a>

                            <a href="#" class="tag-cloud-link">
                                Blog
                            </a>

                        </div>

                    </div>

                    <div class="about-author d-flex p-4 bg-light rounded">

                        <div class="bio mr-5">

                            <img src="<?php echo e(asset('assets/images/default-user.png')); ?>" class="img-fluid mb-4" width="120">

                        </div>

                        <div class="desc">

                            <h3>Admin</h3>

                            <p>
                                Published on
                                <?php echo e($blog->created_at->format('d M Y')); ?>

                            </p>

                        </div>

                    </div>

                </div> <!-- .col-md-8 -->
                <div class="col-lg-4 sidebar pl-md-4">
                    <div class="sidebar-box bg-light rounded">
                        <form action="#" class="search-form">
                            <div class="form-group">
                                <span class="icon fa fa-search"></span>
                                <input type="text" class="form-control" placeholder="Search...">
                            </div>
                        </form>
                    </div>
                    <div class="sidebar-box">
                        <div class="categories">
                            <h3>Categories</h3>
                            <li><a href="#">Web Design</a></li>
                            <li><a href="#">Illustration</a></li>
                            <li><a href="#">Branding</a></li>
                            <li><a href="#">Graphic Design</a></li>
                        </div>
                    </div>

                    <div class="sidebar-box">
                        <h3>Recent Blog</h3>
                        <div class="block-21 mb-4 d-flex">
                            <a class="blog-img mr-4"
                                style="background-image: url(https://preview.colorlib.com/theme/atorni/images/image_1.jpg);"></a>
                            <div class="text">
                                <h3 class="heading"><a href="#">Far far away, behind the word mountains</a></h3>
                                <div class="meta">
                                    <div><a href="#"><span class="fa fa-calendar"></span> November 23, 2020</a>
                                    </div>
                                    <div><a href="#"><span class="fa fa-user"></span> Admin</a></div>
                                    <div><a href="#"><span class="fa fa-comment"></span> 19</a></div>
                                </div>
                            </div>
                        </div>
                        <div class="block-21 mb-4 d-flex">
                            <a class="blog-img mr-4"
                                style="background-image: url(https://preview.colorlib.com/theme/atorni/images/image_2.jpg);"></a>
                            <div class="text">
                                <h3 class="heading"><a href="#">Far far away, behind the word mountains</a></h3>
                                <div class="meta">
                                    <div><a href="#"><span class="fa fa-calendar"></span> November 23, 2020</a>
                                    </div>
                                    <div><a href="#"><span class="fa fa-user"></span> Admin</a></div>
                                    <div><a href="#"><span class="fa fa-comment"></span> 19</a></div>
                                </div>
                            </div>
                        </div>
                        <div class="block-21 mb-4 d-flex">
                            <a class="blog-img mr-4"
                                style="background-image: url(https://preview.colorlib.com/theme/atorni/images/image_3.jpg);"></a>
                            <div class="text">
                                <h3 class="heading"><a href="#">Far far away, behind the word mountains</a></h3>
                                <div class="meta">
                                    <div><a href="#"><span class="fa fa-calendar"></span> November 23, 2020</a>
                                    </div>
                                    <div><a href="#"><span class="fa fa-user"></span> Admin</a></div>
                                    <div><a href="#"><span class="fa fa-comment"></span> 19</a></div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="sidebar-box">
                        <h3>Tag Cloud</h3>
                        <div class="tagcloud">
                            <a href="#" class="tag-cloud-link">law</a>
                            <a href="#" class="tag-cloud-link">atty</a>
                            <a href="#" class="tag-cloud-link">attorney</a>
                            <a href="#" class="tag-cloud-link">criminal</a>
                            <a href="#" class="tag-cloud-link">court</a>
                            <a href="#" class="tag-cloud-link">appeal</a>
                            <a href="#" class="tag-cloud-link">family</a>
                            <a href="#" class="tag-cloud-link">legal</a>
                            <a href="#" class="tag-cloud-link">advice</a>
                        </div>
                    </div>

                    <div class="sidebar-box">
                        <h3>Paragraph</h3>
                        <p>Lorem ipsum dolor sit amet, consectetur adipisicing elit. Ducimus itaque, autem necessitatibus
                            voluptate quod mollitia delectus aut, sunt placeat nam vero culpa sapiente consectetur
                            similique, inventore eos fugit cupiditate numquam!</p>
                    </div>
                </div>

            </div>
        </div>
    </section>




    <?php echo $__env->make('website.partials.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('website.main', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/website/blogs.blade.php ENDPATH**/ ?>