<?php $__env->startSection('main-content'); ?>

    <section class="hero-wrap hero-wrap-2" style="background-image: url('<?php echo e(asset('assets/images/bag2.webp')); ?>');">
        <div class="overlay"></div>
        <div class="container">
            <div class="row no-gutters slider-text align-items-center justify-content-center">
                <div class="col-md-9 pt-5 text-center">
                    <p class="breadcrumbs"><span class="mr-2"><a href="index.html">Home <i
                                    class="fa fa-chevron-right"></i></a></span> <span>Our Blogs <i
                                class="fa fa-chevron-right"></i></span></p>
                    <h1 class="mb-0 bread">Our Blogs</h1>
                </div>
            </div>
        </div>
    </section>

       <style>
        .blog-entry {
            background: #fff;
            border-radius: 12px;
            overflow: hidden;
            transition: .3s;
            height: 100%;
            border: 1px solid #eee;
        }

        .blog-entry:hover {
            transform: translateY(-8px);
            box-shadow: 0 15px 35px rgba(0, 0, 0, .12);
        }

        .blog-entry .img {
            height: 260px;
            background-size: cover;
            background-position: center;
            position: relative;
        }

        /* Date Circle */
        .blog-entry .meta {
            position: absolute;
            left: 20px;
            bottom: 20px;
        }

        .blog-entry .meta div {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            background: #1F3044;
            color: #fff;
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
            box-shadow: 0 8px 20px rgba(31, 48, 68, .35);
        }

        .blog-entry .day {
            font-size: 26px;
            font-weight: 700;
            line-height: 1;
        }

        .blog-entry .mos {
            font-size: 13px;
            text-transform: uppercase;
            font-weight: 600;
        }

        .blog-entry .yr {
            font-size: 11px;
        }

        /* Content */
        .blog-entry .text {
            display: flex;
            flex-direction: column;
            padding: 25px;
            height: 250px;
        }

        .blog-entry h3 {
            font-size: 24px;
            font-weight: 700;
            line-height: 1.5;
            min-height: 80px;
        }

        .blog-entry h3 a {
            color: #1F3044;
            text-decoration: none;
        }

        .blog-entry h3 a:hover {
            color: #1F3044;
        }

        .blog-desc {
            flex: 1;
            color: #666;
            line-height: 1.8;
            margin-bottom: 20px;
        }

        .read-btn {
            background: #1F3044;
            color: #fff;
            padding: 12px 25px;
            border-radius: 30px;
            text-decoration: none;
            display: inline-block;
            font-weight: 600;
            transition: .3s;
            align-self: flex-start;
        }

        .read-btn:hover {
            background: #152536;
            color: #fff;
        }
    </style>


    <section class="ftco-section" style="background:#F5F7FA;">

        <div class="container-xl">

            <div class="row justify-content-center mb-5">

                <div class="col-md-7 heading-section text-center" data-aos="fade-up">

                    <span class="subheading">
                        Legal Insights & Blog
                    </span>

                    <h2>
                        Latest Legal Articles
                    </h2>

                </div>

            </div>

            <div class="row">

                <?php $__empty_1 = true; $__currentLoopData = $blogs; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $blog): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                    <div class="col-lg-4 col-md-6 mb-4">

                        <div class="blog-entry" data-aos="fade-up">

                            <a href="<?php echo e(route('blog.details', $blog->slug)); ?>" class="img d-block"
                                style="background-image:url('<?php echo e(asset('uploads/blogs/' . $blog->image)); ?>');">

                                <div class="meta">

                                    <div>

                                        <span class="day">
                                            <?php echo e($blog->created_at->format('d')); ?>

                                        </span>

                                        <span class="mos">
                                            <?php echo e(strtoupper($blog->created_at->format('M'))); ?>

                                        </span>

                                        <span class="yr">
                                            <?php echo e($blog->created_at->format('Y')); ?>

                                        </span>

                                    </div>

                                </div>

                            </a>

                            <div class="text">

                                <h3>

                                    <a href="<?php echo e(route('blog.details', $blog->slug)); ?>">

                                        <?php echo e($blog->title); ?>


                                    </a>

                                </h3>

                                <p class="blog-desc">

                                    <?php echo e(\Illuminate\Support\Str::limit($blog->short_description, 120)); ?>


                                </p>

                                <a href="<?php echo e(route('blog.details', $blog->slug)); ?>" class="read-btn">

                                    Read More

                                    <i class="fa fa-arrow-right ms-2"></i>

                                </a>

                            </div>

                        </div>

                    </div>

                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>

                    <div class="col-12">

                        <div class="alert alert-warning text-center">

                            No Blogs Available.

                        </div>

                    </div>
                <?php endif; ?>

            </div>

        </div>

    </section>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('website.main', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/website/blog.blade.php ENDPATH**/ ?>