<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use Illuminate\Http\Request;

class WebsiteController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Home Page
    |--------------------------------------------------------------------------
    */

    public function index()
    {
        $blogs = Blog::where('status', 'active')
            ->latest()
            ->paginate(9);

        return view('website.index', compact('blogs'));
    }

    /*
    |--------------------------------------------------------------------------
    | Static Pages
    |--------------------------------------------------------------------------
    */

    public function about()
    {
        return view('website.about');
    }

    public function service()
    {
        return view('website.service');
    }

    public function practiceAreas()
    {
        return view('website.practice-areas');
    }

    public function team()
    {
        return view('website.team');
    }

    public function careers()
    {
        return view('website.career');
    }

    public function contact()
    {
        return view('website.contact');
    }

    /*
    |--------------------------------------------------------------------------
    | Individual Service Pages
    |--------------------------------------------------------------------------
    */

    public function commercialFinancialDisputes()
    {
        return view('website.services.Commercial_Financial_Disputes');
    }

    public function commercialContracts()
    {
        return view('website.services.Commercial_Litigation');
    }

    public function commercialLitigation()
    {
        return view('website.services.Commercial_Litigation');
    }

    public function taxDisputes()
    {
        return view('website.services.Tax_Disputes');
    }

    public function labourEmployment()
    {
        return view('website.services.labour_law_Emp');
    }

    public function foreignInvestment()
    {
        return view('website.services.Foreign_Investment');
    }

    public function intellectualProperty()
    {
        return view('website.services.Intellectual_Property');
    }

    public function bankingFinance()
    {
        return view('website.services.Banking_Finance');
    }

    public function commercialArbitration()
    {
        return view('website.services.Commercial Arbitration');
    }

    public function bankruptcy()
    {
        return view('website.services.Bankruptcy');
    }

    public function corporateLaw()
    {
        return view('website.services.Corporate_Law_Governance');
    }
}
