
<section class="ftco-intro img"
    style="background-image: url('<?php echo e(asset('assets/images/bg_4.jpg')); ?>');
           background-size: cover;
           background-position: center;
           background-repeat: no-repeat;">

    <div class="overlay"></div>

    <div class="container-xl">
        <div class="row justify-content-center">
            <div class="col-md-12 heading-section heading-section-white text-center">
                <h2 class="mb-4">Need a Legal Advisor?</h2>

                <p class="mb-0">
                    <a href="tel:+966554944497" class="btn btn-black">+966-554944497</a>

                    <a href="mailto:naser@aljubail.lawyer" class="btn btn-white">
                        naser@aljubail.lawyer
                    </a>
                </p>
            </div>
        </div>
    </div>

</section>

<style>
    .ftco-footer {
        position: relative;
        background: url(<?php echo e(asset('assets/images/footer_bg.webp')); ?>);
        overflow: hidden;
    }

    /* Black Overlay */

    .ftco-footer::before {
        content: "";
        position: absolute;
        inset: 0;
        background: rgba(31, 48, 68, 0.8);
        z-index: 1;
    }

    /* Footer Content */

    .ftco-footer .container-xl,
    .ftco-footer .container-fluid {
        position: relative;
        z-index: 2;
    }
</style>


<footer class="ftco-footer">
    <div class="container-xl">
        <div class="row justify-content-between">

            <div class="col-md-6 col-lg">
                <div class="ftco-footer-widget mb-4">
                    <div style="margin-bottom:20px;">
                        <a href="<?php echo e(route('home')); ?>">
                            <img src="<?php echo e(asset('assets/images/logotrasn.png ')); ?>" alt="Aljubail Law Firm Logo"
                                class="img-fluid" style="max-width:220px;height:auto;display:block;">
                        </a>
                    </div>

                    <p>
                        Client-Focused Law Firm. We prioritize our clients' needs, providing tailored legal
                        solutions with professionalism and excellence since 2018.
                    </p>

                    <ul class="ftco-footer-social list-unstyled mt-2">
                        <li><a href="#"><span class="fa fa-twitter"></span></a></li>
                        <li><a href="#"><span class="fa fa-facebook"></span></a></li>
                        <li><a href="#"><span class="fa fa-instagram"></span></a></li>
                    </ul>
                </div>
            </div>

            <div class="col-md-6 col-lg-4">
                <div class="ftco-footer-widget mb-4">
                    <h2 class="ftco-heading-2">Recent Posts</h2>

                    <div class="block-21 mb-4 d-flex">
                        <a class="img mr-4 rounded"
                            style="background-image:url(<?php echo e(asset('assets/images/image_1.jpg')); ?>;"></a>
                        <div class="text">
                            <h3 class="heading">
                                <a href="https://aljubail.lawyer/web/en/how-to-select-the-appropriate-attorney-for-your-case-in-saudi-arabia/">
                                    How to Select the Appropriate Attorney for Your Case?
                                </a>
                            </h3>
                            <div class="meta">
                                <div><a href="#"><span class="fa fa-calendar"></span> Oct. 19, 2025</a></div>
                                <div><a href="#"><span class="fa fa-user"></span> Admin</a></div>
                            </div>
                        </div>
                    </div>

                    <div class="block-21 mb-4 d-flex">
                        <a class="img mr-4 rounded"
                            style="background-image: url('<?php echo e(asset('assets/images/image_2.jpg')); ?>');">
                        </a>
                        <div class="text">
                            <h3 class="heading">
                                <a href="https://aljubail.lawyer/web/en/how-technology-affects-the-legal-sector/">
                                    How Technology Affects the Legal Sector?
                                </a>
                            </h3>
                            <div class="meta">
                                <div><a href="#"><span class="fa fa-calendar"></span> Oct. 19, 2025</a></div>
                                <div><a href="#"><span class="fa fa-user"></span> Admin</a></div>
                            </div>
                        </div>
                    </div>

                </div>
            </div>

            <div class="col-md-6 col-lg-2">
                <div class="ftco-footer-widget mb-4">
                    <h2 class="ftco-heading-2">Explore</h2>

                    <ul class="list-unstyled">
                        <li><a href="#"><span class="fa fa-chevron-right mr-2"></span>About Us</a></li>
                        <li><a href="#"><span class="fa fa-chevron-right mr-2"></span>Our Services</a></li>
                        <li><a href="#"><span class="fa fa-chevron-right mr-2"></span>Case Studies</a></li>
                        <li><a href="#"><span class="fa fa-chevron-right mr-2"></span>Our Teams</a></li>
                        <li><a href="#"><span class="fa fa-chevron-right mr-2"></span>Blog</a></li>
                    </ul>
                </div>
            </div>

            <div class="col-md-6 col-lg">
                <div class="ftco-footer-widget mb-4">
                    <h2 class="ftco-heading-2">Have a Questions?</h2>

                    <div class="block-23 mb-3">
                        <ul>
                            <li>
                                <span class="icon fa fa-map marker"></span>
                                <span class="text">Riyadh Al-Ulya, King Fahd Road, Marabaa Tower</span>
                            </li>
                            <li>
                                <a href="tel:+966554944497">
                                    <span class="icon fa fa-phone"></span>
                                    <span class="text">+966-554944497</span>
                                </a>
                            </li>
                            <li>
                                <a href="#">
                                    <span class="icon fa fa-paper-plane pr-4"></span>
                                    <span class="text">naser@aljubail.lawyer</span>
                                </a>
                            </li>
                        </ul>
                    </div>

                </div>
            </div>

        </div>
    </div>
</footer>
<script>
        document.addEventListener("DOMContentLoaded", function() {

            const menuToggle = document.getElementById("menuToggle");
            const closeMenu = document.getElementById("closeMenu");
            const mobileMenu = document.querySelector(".mobile-menu");
            const overlay = document.querySelector(".mobile-overlay");

            menuToggle.addEventListener("click", function() {

                mobileMenu.classList.add("active");
                overlay.classList.add("active");
                document.body.style.overflow = "hidden";

            });

            function closeSidebar() {

                mobileMenu.classList.remove("active");
                overlay.classList.remove("active");
                document.body.style.overflow = "auto";

            }

            closeMenu.addEventListener("click", closeSidebar);
            overlay.addEventListener("click", closeSidebar);

            document.querySelectorAll(".mobile-dropdown > a").forEach(function(item) {

                item.addEventListener("click", function(e) {

                    e.preventDefault();

                    let submenu = this.nextElementSibling;

                    submenu.style.display =
                        submenu.style.display === "block" ? "none" : "block";

                    let icon = this.querySelector("i");

                    icon.classList.toggle("fa-angle-down");
                    icon.classList.toggle("fa-angle-up");

                });

            });

        });
    </script>
<script src="<?php echo e(asset('assets/js/bootstrap.bundle.min.js')); ?>"></script>
<script src="<?php echo e(asset('assets/js/tiny-slider.js')); ?>"></script>
<script src="<?php echo e(asset('assets/js/aos.js')); ?>"></script>
<script src="<?php echo e(asset('assets/js/main.js')); ?>"></script>
<script>
    AOS.init();
</script>

</body>

</html>
<?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/website/partials/footer.blade.php ENDPATH**/ ?>