
<section class="slider-hero">

    <div class="hero-slider owl-carousel">

        <!-- Slide 1 -->
        <div class="item">
            <div class="img js-fullheight d-flex align-items-center"
                style="background-image:  url('<?php echo e(asset('assets/images/bg-1.webp')); ?>');">

                <div class="overlay"></div>

                <div class="container-xl">
                    <div class="row">
                        <div class="col-lg-6 col-md-8">

                            <div class="text">

                                <h2>Legal Experts — Tailored Legal Solutions with Client Focus</h2>

                                <p>
                                    Client-Focused Law Firm. We prioritize our clients' needs,
                                    providing tailored legal solutions with professionalism
                                    and excellence.
                                </p>

                                <a href="#appoinment" class="btn btn-primary px-5 py-3">
                                    Make An Appointment
                                </a>

                            </div>

                        </div>
                    </div>
                </div>

            </div>
        </div>

        <!-- Slide 2 -->
        <div class="item">

            <div class="img js-fullheight d-flex align-items-center"
                style="background-image: url('<?php echo e(asset('assets/images/bg-2.webp')); ?>');">

                <div class="overlay"></div>

                <div class="container-xl">
                    <div class="row">
                        <div class="col-lg-6 col-md-8">

                            <div class="text">

                                <h2>Comprehensive Legal Services Since 2018</h2>

                                <p>
                                    A comprehensive and integrated set of specialized and
                                    reliable legal services and consultations delivered
                                    according to high-quality standards.
                                </p>

                                <a href="#appoinment" class="btn btn-primary px-5 py-3">
                                    Make An Appointment
                                </a>

                            </div>

                        </div>
                    </div>
                </div>

            </div>

        </div>

        <!-- Slide 3 -->
        <div class="item">
            <div class="img js-fullheight d-flex align-items-center"
                style="background-image:url(<?php echo e(asset('assets/images/bg_4.jpg')); ?>">
                <div class="overlay"></div>
                <div class="container-xl">
                    <div class="row">
                        <div class="col-lg-6 col-md-8">

                            <div class="text">

                                <h2>Clear Advice, Trusted Representation</h2>

                                <p>
                                    By understanding every client's legal requirements,
                                    we deliver personalized legal services with integrity,
                                    efficiency and professionalism.
                                </p>

                                <a href="#appoinment" class="btn btn-primary px-5 py-3">
                                    Make An Appointment
                                </a>

                            </div>

                        </div>
                    </div>
                </div>

            </div>

        </div>

    </div>

</section>
<?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/website/partials/heroslider.blade.php ENDPATH**/ ?>