<!DOCTYPE html>
<html lang="en">
<?php echo $__env->make('dashboard.partials.head', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

<body>
    <div class="wrapper">
      <?php echo $__env->make('dashboard.partials.sidebar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

        <div class="main">
            <?php echo $__env->make('dashboard.partials.navbar', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>

            <main class="content">
                <div class="container-fluid p-0">




                    <div class="row">
                        <div class="col-12 d-flex">




                                <?php echo $__env->yieldContent('main-content'); ?>


                        </div>

                    </div>

                </div>
            </main>
            <?php echo $__env->make('dashboard.partials.footer', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?>
        </div>
    </div>

    <script src="<?php echo e(asset('dashboard_assets/js/app.js')); ?>"></script>


</body>

</html>
<?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/dashboard/main.blade.php ENDPATH**/ ?>