<div class="sidebar-content js-simplebar">

    <!-- Logo -->
    <a href="<?php echo e(route('dashboard')); ?>"
        class="sidebar-brand"
        style="display:flex;
               justify-content:center;
               align-items:center;
               padding:20px 15px;
               background:#1F3044;
               border-bottom:1px solid rgba(255,255,255,.15);">

        <img src="<?php echo e(asset('assets/images/logotrasn.png')); ?>"
            alt="Al Jubail Law Firm"
            style="max-width:180px;
                   width:100%;
                   height:auto;
                   object-fit:contain;">

    </a>

    <ul class="sidebar-nav">

        <li class="sidebar-header">
            Dashboard
        </li>

        <!-- Dashboard -->
        <li class="sidebar-item <?php echo e(request()->routeIs('dashboard') ? 'active' : ''); ?>">
            <a class="sidebar-link" href="<?php echo e(route('dashboard')); ?>">
                <i class="align-middle" data-feather="home"></i>
                <span class="align-middle">Dashboard</span>
            </a>
        </li>

        <!-- Users -->
        <li class="sidebar-item <?php echo e(request()->routeIs('users.*') || request()->routeIs('user.*') ? 'active' : ''); ?>">
            <a class="sidebar-link" href="<?php echo e(route('users.show')); ?>">
                <i class="align-middle" data-feather="users"></i>
                <span class="align-middle">Users</span>
            </a>
        </li>

        <!-- Blogs -->
        <li class="sidebar-item <?php echo e(request()->routeIs('blogs.*') ? 'active' : ''); ?>">
            <a class="sidebar-link" href="<?php echo e(route('blogs.index')); ?>">
                <i class="align-middle" data-feather="book-open"></i>
                <span class="align-middle">Blogs</span>
            </a>
        </li>

        <!-- Contact Messages -->
        <li class="sidebar-item <?php echo e(request()->routeIs('contacts.*') ? 'active' : ''); ?>">
            <a class="sidebar-link" href="<?php echo e(route('contacts.show')); ?>">
                <i class="align-middle" data-feather="mail"></i>
                <span class="align-middle">Contact Messages</span>
            </a>
        </li>

        <!-- Job Applications -->
        <li class="sidebar-item <?php echo e(request()->routeIs('applications.*') ? 'active' : ''); ?>">
            <a class="sidebar-link" href="<?php echo e(route('applications.index')); ?>">
                <i class="align-middle" data-feather="briefcase"></i>
                <span class="align-middle">Job Applications</span>
            </a>
        </li>

        <!-- View Website -->
        <li class="sidebar-item">
            <a class="sidebar-link" href="<?php echo e(route('home')); ?>" target="_blank">
                <i class="align-middle" data-feather="globe"></i>
                <span class="align-middle">View Website</span>
            </a>
        </li>

        <li class="sidebar-header">
            Account
        </li>

        <!-- Logout -->
        <li class="sidebar-item">
            <a class="sidebar-link"
                href="<?php echo e(route('logout')); ?>"
                onclick="return confirm('Are you sure you want to logout?')">

                <i class="align-middle" data-feather="log-out"></i>
                <span class="align-middle">Logout</span>

            </a>
        </li>

    </ul>

</div>
<?php /**PATH C:\Users\LAPOP CLINIC\Desktop\New folder (2)\Aljubail_web\resources\views/dashboard/partials/sidebar.blade.php ENDPATH**/ ?>