
<style>
    .award-wrap {
        background: #fff;
        border-radius: 12px;
        padding: 35px 25px;
        text-align: center;
        box-shadow: 0 8px 25px rgba(0, 0, 0, .08);
        transition: .35s;
        /* height:340px; */
        margin: 10px 30px;
        width: 16vw;
        display: flex;
        align-items: center;
        justify-content: center;
    }

    .award-wrap img {
        max-width: 100%;
        max-height: 160px;
        width: auto;
        transition: .35s;
    }

    .award-wrap:hover {
        transform: translateY(-8px);
        box-shadow: 0 15px 35px rgba(0, 0, 0, .12);
        background-color: #F5F7FA;
    }

    .award-wrap:hover img {
        transform: scale(1.08);
    }
</style>

<section class="ftco-section testimony-section bg-light">
    <div class="container-xl">
        <div class="row justify-content-center pb-4">
            <div class="col-md-7 text-center heading-section">
                <span class="subheading">Recognition</span>
                <h2 class="mb-3">Awards & Achievements</h2>
                <p>Recognized for excellence in legal services.</p>
            </div>
        </div>
        <div class="row">
            <div class="col-md-12" data-aos="fade-up" data-aos-duration="1000" data-aos-delay="100">




                <div class="carousel-testimony  owl-carousel d-flex">

                    <div class="item">
                        <div class="award-wrap">
                            <img src="{{ asset('assets/images/award-1.png') }}" alt="Award 1">
                        </div>
                    </div>

                    <div class="item">
                        <div class="award-wrap">
                            <img src="{{ asset('assets/images/award-2.png ') }}" alt="Award 2">
                        </div>
                    </div>

                    <div class="item">
                        <div class="award-wrap">
                            <img src="{{ asset('assets/images/award-3.png ') }}" alt="Award 3">
                        </div>
                    </div>

                    <div class="item">
                        <div class="award-wrap">
                            <img src="{{ asset('assets/images/award-4.png ') }}" alt="Award 4">
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>

